@@ -1,17 +1,3 @@
-# Copyright 2018 Markus Scheidgen
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#   http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an"AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 ''' An example metainfo package. '''
 
 import numpy as np
@@ -63,10 +49,9 @@ class System(MSection):
 
     lattice_vectors = Quantity(
         type=np.dtype('f'), shape=[3, 3], unit=ureg.m, categories=[SystemHash],
+        aliases=['unit_cell'],
         description='The lattice vectors of the simulated unit cell.')
 
-    unit_cell = Quantity(synonym_for='lattice_vectors')
-
     periodic_dimensions = Quantity(
         type=bool, shape=[3], default=[False, False, False], categories=[SystemHash],
         description='A vector of booleans indicating in which dimensions the unit cell is repeated.')
